import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  line,
  max
} from 'd3';

//svg tag for html
const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

//A Line graph
const render = data => { 
  // constants used in the graph
  const title = 'Sales from 2001 to 2010';
  
  const xValue = d => d.Year; // year on the x axis
  const xAxisLabel = 'Year';

  const yValue = d => d.Sales; //sales value for y axis
  const yAxisLabel = 'Sales';
  
  const margin = { top: 50, right: 40, bottom: 85, left: 150 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;

  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  const xScale = scaleTime()
  //set of values
    .domain(extent(data, xValue)) 
    .range([0, innerWidth]) //output bounds
    .nice(); 
  // xAxis  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);
  
  // Create Y scale with sales values
  const yScale = scaleLinear()
    .domain([0, max(data, yValue )])
    .range([innerHeight, 0])
    .nice();
  
  //creating y-Axis  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);
  const yAxisG = g.append('g').call(yAxis);
  	yAxisG.selectAll('.domain').remove();
  	yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -90)
      .attr('x', -innerHeight / 3)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .text(yAxisLabel);
  const xAxisG = g.append('g').call(xAxis)
    	.attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 70)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  
  //line graphs between x and y axis
  const lineGenerator = line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue(d))); 
  g.append('path')
  	.attr('class', 'line_path')
  	.attr('d', lineGenerator(data))
  //Attaching the title of graph to svg
  g.append('text')
      .attr('class', 'title')
      .attr('y', -10)
      .text(title);
};
csv('https://gist.githubusercontent.com/eravellisaimeghana/302958576ab0e8235b88e53e3dc9872f/raw/8cd6902ce0662c91bf5202eb7dd1f1d1882ae109/salesofcars.csv')
  .then(data => {
    data.forEach(d => {
    	d.Sales = +d.sales;
      d.Year = new Date(d.year)
    });
    render(data);
  });